@@ -24,8 +24,8 @@
  * CSV̲
  *
  * $RCSfile: result.php,v $
- * $Revision: 1.7 $
- * $Date: 2012/09/13 02:58:51 $
+ * $Revision: 1.8 $
+ * $Date: 2013/09/05 06:08:29 $
  **********************************************************/
 
 include_once("../../initial");
@@ -606,7 +606,7 @@ function read_csvfile($fp, $logstr)
 
         /* ޤǶڤ */
         $tmpline = rtrim($tmpline);
-        $csvdata = explode(",", $tmpline);
+        $csvdata = parse_csv($tmpline);
 
         /* ͤν */
         $err_msg = "";
@@ -667,6 +667,39 @@ function read_csvfile($fp, $logstr)
     return TRUE;
 }
 
+/***********************************************************
+ * parse_csv
+ *
+ * csv
+ *
+ * []
+ *        $line        csv1
+ *
+ * []
+ *        $parse[1]    
+ *
+ **********************************************************/
+function parse_csv($line)
+{
+    $parse = array();
+    $rep_str = array();
+
+    // "",,
+    preg_match_all('/("[^"]*(""[^"]*)*"|[^,]*),?/', $line, $parse);
+
+    // 
+    array_pop($parse[1]);
+
+    // "",
+    foreach($parse[1] as $key => $value) {
+        // "("")"
+        if(preg_match('/^"(.*)"$/', $value, $rep_str)) {
+            $parse[1][$key] = preg_replace('/""/', '"', $rep_str[1]);
+        }
+    }
+    return $parse[1];
+}
+
 /***********************************************************
  * print_csv_result
  *
