@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.15 $
- * $Date: 2012/09/26 06:33:03 $
+ * $Revision: 1.17 $
+ * $Date: 2013/09/05 06:08:59 $
  **********************************************************/
 
 include_once("../../initial");
@@ -68,11 +68,11 @@ function set_tag_data($post, $form_name, $ldap_result, $filter_disp, $form_name_
     /* JavaScript */
     $javascript = <<<EOD
     function allSubmit(url, page, dn, form_name_encode) {
-        document.all.action = url;
-        document.all.page.value = page;
-        document.all.dn.value = dn;
-        document.all.form_name.value = form_name_encode;
-        document.all.submit();
+        document.form_main.action = url;
+        document.form_main.page.value = page;
+        document.form_main.dn.value = dn;
+        document.form_main.form_name.value = form_name_encode;
+        document.form_main.submit();
     }
 
 EOD;
@@ -109,6 +109,7 @@ EOD;
     /* ڡڡ */
     $tag["<<PRE>>"] = "";
     $tag["<<NEXT>>"] = "";
+    $tag["<<MAXPASSLEN>>"] = "";
 
     get_page($ldap_result, $page, $form_name_encode, $tag);
 
